@@ -1,7 +1,4 @@
-# -*- coding: utf-8 -*-
 """SatNOGS Network Auth0 login module test suites"""
-from __future__ import unicode_literals
-
 # from django.test import TestCase
 
 # Create your tests here.
