@@ -6,7 +6,8 @@ from django.shortcuts import redirect, render
 from django.urls import reverse
 
 from network.base.decorators import admin_required
-from network.base.tasks import fetch_data, update_all_tle
+from network.base.tasks import fetch_data, update_all_tle, \
+    update_future_observations_with_new_tle_sets
 
 
 def index(request):
@@ -32,6 +33,7 @@ def settings_site(request):
     if request.method == 'POST':
         fetch_data.delay()
         update_all_tle.delay()
+        update_future_observations_with_new_tle_sets.delay()
         messages.success(request, 'Data fetching task was triggered successfully!')
         return redirect(reverse('users:view_user', kwargs={"username": request.user.username}))
     return render(request, 'base/settings_site.html')
